==> dojo-1.9.4.tgz: package/cldr/nls/zh/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "星期",
	"dateFormatItem-yQQQ": "y年第Q季度",
	"dateFormatItem-yMEd": "y/M/dE",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"公元前",
		"公元"
	],
	"dateFormatItem-yMM": "y年M月",
	"dayPeriods-format-wide-earlyMorning": "清晨",
	"dayPeriods-format-wide-morning": "上午",
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormat-long": "y年M月d日",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "y年M月d日EEEE",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-narrow-midDay": "中午",
	"dayPeriods-format-wide-noon": "中午",
	"dateFormatItem-yMd": "y/M/d",
	"dateFormatItem-yM": "y/M",
	"field-era": "时期",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"timeFormat-long": "zah:mm:ss",
	"dateFormatItem-yMMM": "y年M月",
	"dateFormatItem-yQQQQ": "y年QQQQ",
	"field-year": "年",
	"dateFormatItem-MMdd": "MM/dd",
	"field-hour": "小时",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-full": "zzzzah:mm:ss",
	"dayPeriods-format-narrow-morning": "上午",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "后天",
	"dateFormatItem-H": "H时",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"timeFormat-medium": "ah:mm:ss",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"eraAbbr": [
		"公元前",
		"公元"
	],
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dayPeriods-format-wide-night": "晚上",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah时",
	"dateTimeFormat-long": "{1}{0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-wide-midDay": "中午",
	"dateFormatItem-MEd": "M/dE",
	"dateTimeFormat-full": "{1}{0}",
	"dateFormatItem-yMMMM": "y年M月",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "时区",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormatItem-y": "y年",
	"field-year-relative+-1": "去年",
	"dayPeriods-format-narrow-night": "晚上",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-hm": "ah:mm",
	"dayPeriods-format-narrow-weeHours": "凌晨",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"eraNames": [
		"公元前",
		"公元"
	],
	"dateFormatItem-yMMMd": "y年M月d日",
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-narrow-earlyMorning": "清晨",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "月",
	"dayPeriods-format-wide-am": "上午",
	"dayPeriods-format-wide-weeHours": "凌晨",
	"dateFormatItem-MMMMdd": "M月dd日",
	"dateFormat-short": "yy-M-d",
	"dayPeriods-format-wide-afternoon": "下午",
	"dayPeriods-format-narrow-afternoon": "下午",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒钟",
	"dateFormatItem-yMMMEd": "y年M月d日E",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "y年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/zh/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "Eah:mm",
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "现在",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "工作日",
	"dateFormatItem-yQQQ": "y年第Q季度",
	"dateFormatItem-yMEd": "y/M/dE",
	"field-wed-relative+0": "本周三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"field-wed-relative+1": "下周三",
	"eraNarrow": [
		"公元前",
		"公元"
	],
	"dateFormatItem-yMM": "y年M月",
	"dayPeriods-format-wide-earlyMorning": "清晨",
	"field-tue-relative+-1": "上周二",
	"dayPeriods-format-wide-morning": "上午",
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormat-long": "y年M月d日",
	"field-fri-relative+-1": "上周五",
	"field-wed-relative+-1": "上周三",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "y年M月d日EEEE",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-narrow-midDay": "中午",
	"dayPeriods-format-wide-noon": "中午",
	"dateFormatItem-yMd": "y/M/d",
	"dateFormatItem-yM": "y年M月",
	"field-era": "纪元",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"timeFormat-long": "z ah:mm:ss",
	"dateFormatItem-yMMM": "y年M月",
	"dateFormatItem-yQQQQ": "y年第Q季度",
	"field-year": "年",
	"dateFormatItem-MMdd": "MM/dd",
	"field-hour": "小时",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"timeFormat-full": "zzzz ah:mm:ss",
	"dayPeriods-format-narrow-morning": "上午",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-thu-relative+0": "本周四",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "后天",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-H": "H时",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"timeFormat-medium": "ah:mm:ss",
	"field-sun-relative+0": "本周日",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"field-sun-relative+1": "下周日",
	"eraAbbr": [
		"公元前",
		"公元"
	],
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dayPeriods-format-wide-night": "晚上",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah时",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-wide-midDay": "中午",
	"dateFormatItem-MEd": "M/dE",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "本周五",
	"dateFormatItem-yMMMM": "y年M月",
	"field-fri-relative+1": "下周五",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "时区",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormatItem-y": "y年",
	"field-year-relative+-1": "去年",
	"dayPeriods-format-narrow-night": "晚上",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-hm": "ah:mm",
	"dayPeriods-format-narrow-weeHours": "凌晨",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"eraNames": [
		"公元前",
		"公元"
	],
	"dateFormatItem-yMMMd": "y年M月d日",
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-narrow-earlyMorning": "清晨",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "月",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"dayPeriods-format-wide-am": "上午",
	"dateFormatItem-EHm": "EHH:mm",
	"dayPeriods-format-wide-weeHours": "凌晨",
	"dateFormatItem-MMMMdd": "M月dd日",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"dateFormat-short": "yy/M/d",
	"dayPeriods-format-wide-afternoon": "下午",
	"dateFormatItem-EHms": "EHH:mm:ss",
	"dateFormatItem-Ehms": "Eah:mm:ss",
	"dayPeriods-format-narrow-afternoon": "下午",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒钟",
	"field-sat-relative+-1": "上周六",
	"dateFormatItem-yMMMEd": "y年M月d日E",
	"field-sun-relative+-1": "上周日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"dateTimeFormats-appendItem-Timezone": "{1}{0}",
	"field-week": "周",
	"dateFormat-medium": "y年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上周一",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);
